@@ -28,6 +28,8 @@ std::auto_ptr<mosca::fiera_config> fors_ccd_settings_equal(const cpl_frameset *
 void fors_update_ccd_ron(mosca::ccd_config ccd_config, 
                          cpl_propertylist * master_bias_header);
 
+std::auto_ptr<mosca::fiera_config>  fors_ccd_config_read
+(const cpl_frame * target, const cpl_frame * bias_frame);
 
 #endif /* FORS_CCD_CONFIG_H */
 
