@@ -300,22 +300,34 @@ fors_dfs_set_groups(cpl_frameset * set)
                      strcmp(tag, "MASTER_NORM_FLAT_MOS"         ) == 0 ||
                      strcmp(tag, "MASTER_NORM_FLAT_MXU"         ) == 0 ||
                      strcmp(tag, "MASTER_NORM_FLAT_LSS"         ) == 0 ||
+                     strcmp(tag, "MASTER_NORM_FLAT_LONG_MOS"    ) == 0 ||
                      strcmp(tag, "SLIT_LOCATION_MOS"            ) == 0 ||
                      strcmp(tag, "SLIT_LOCATION_MXU"            ) == 0 ||
                      strcmp(tag, "SLIT_LOCATION_LSS"            ) == 0 ||
+                     strcmp(tag, "SLIT_LOCATION_LONG_MOS"       ) == 0 ||
                      strcmp(tag, "CURV_COEFF_MOS"               ) == 0 ||
                      strcmp(tag, "CURV_COEFF_MXU"               ) == 0 ||
                      strcmp(tag, "CURV_COEFF_LSS"               ) == 0 ||
                      strcmp(tag, "DISP_COEFF_MOS"               ) == 0 ||
                      strcmp(tag, "DISP_COEFF_MXU"               ) == 0 ||
                      strcmp(tag, "DISP_COEFF_LSS"               ) == 0 ||
+                     strcmp(tag, "DISP_COEFF_LONG_MOS"          ) == 0 ||
+                     strcmp(tag, "FLAT_SED_MOS"            ) == 0 ||
+                     strcmp(tag, "FLAT_SED_MXU"            ) == 0 ||
+                     strcmp(tag, "FLAT_SED_LSS"            ) == 0 ||
+                     strcmp(tag, "FLAT_SED_LONG_MOS"       ) == 0 ||
                      /* static calibration */
                      strcmp(tag, FLX_STD_IMG                    ) == 0 ||
+                     strcmp(tag, "EXTINCT_TABLE"                ) == 0 ||
                      strcmp(tag, "MASTER_LINECAT"               ) == 0 ||
                      strcmp(tag, "MASTER_DISTORTION_TABLE"      ) == 0 ||
+                     strcmp(tag, "GLOBAL_DISTORTION_TABLE"      ) == 0 ||
                      strcmp(tag, "RETARDER_WAVEPLATE_CHROMATISM") == 0 ||
                      strcmp(tag, "GRISM_TABLE"                  ) == 0 ||
                      strcmp(tag, "STD_PMOS_TABLE"               ) == 0 ||
+                     strcmp(tag, "TELLURIC_CONTAMINATION"       ) == 0 ||
+                     strcmp(tag, "STD_FLUX_TABLE"               ) == 0 ||
+                     strcmp(tag, "SPECPHOT_TABLE"               ) == 0 ||
                      strcmp(tag, PHOT_TABLE                     ) == 0) {
                 cpl_frame_set_group(f, CPL_FRAME_GROUP_CALIB);
             }
@@ -915,8 +927,6 @@ cpl_table *dfs_load_table(cpl_frameset *frameset, const char *category, int ext)
             cpl_msg_error(func, "Cannot load table %s",
                           cpl_frame_get_filename(frame));
         }
-        else
-            cpl_frame_set_group(frame, CPL_FRAME_GROUP_CALIB);
     }
 
     return table;
@@ -1196,6 +1206,7 @@ fors_dfs_save_image_mask(cpl_frameset *frameset, const cpl_image *image,
     cpl_image_save(mask, filename, CPL_BPP_IEEE_FLOAT, extension_header,
                    CPL_IO_EXTEND);
     cpl_propertylist_delete(extension_header);
+    cpl_free(filename);
 
 }
 
@@ -1284,6 +1295,7 @@ fors_dfs_save_image_err_mask(cpl_frameset *frameset, const fors_image *image,
     cpl_image_save(mask, filename, CPL_BPP_IEEE_FLOAT, extension_header,
                    CPL_IO_EXTEND);
     cpl_propertylist_delete(extension_header);
+    cpl_free(filename);
 }
 
 #undef cleanup
