@@ -656,8 +656,6 @@ extract_sex(                                const fors_image *image,
         int yradius = 64;
         int plane = 0;
         int extension = 0;
-        float maxima;
-        float minima;
 
         if (vignetted) {
             bsigma = cpl_image_load(filename_sigma_full,
@@ -765,7 +763,6 @@ extract_sex(                                const fors_image *image,
         int i;
         int bkg_rejected = 0;
         int rejected = 0;
-        float *bdata = cpl_image_get_data(bmaxsigma);
         int nx = cpl_image_get_size_x(bmaxsigma);
         int ny = cpl_image_get_size_y(bmaxsigma);
 
