@@ -41,7 +41,7 @@
 #define STRETCH_FACTOR   (1.20)
 
 
-fors::flat_normaliser::flat_normaliser() : m_normalisation_image(NULL)
+fors::flat_normaliser::flat_normaliser() : m_normalisation_image()
 {
 }
 
@@ -81,9 +81,9 @@ fors::flat_normaliser::~flat_normaliser()
  * spatially remapped spectra.
  */ 
 int fors::flat_normaliser::mos_normalise
-(mosca::image& flat, cpl_image *spatial, 
- cpl_table *slits, cpl_table *polytraces, 
- double reference, double blue, double red, 
+(mosca::image& flat, const mosca::wavelength_calibration& wave_cal,
+ cpl_image *spatial, cpl_table *slits, cpl_table *polytraces, 
+ double blue, double red, 
  double dispersion,
  int spa_smooth_radius, int disp_smooth_radius, 
  int spa_fit_polyorder, int disp_fit_nknots,
@@ -147,6 +147,7 @@ int fors::flat_normaliser::mos_normalise
     cpl_image * flat_err = flat.get_cpl_image_err();
 
     
+    double reference = wave_cal.get_refwave();
     rectified = mos_spatial_calibration(flat_im, slits, polytraces, reference,
                                         blue, red, dispersion, 0, NULL);
 
@@ -213,15 +214,22 @@ int fors::flat_normaliser::mos_normalise
                                       spa_fit_polyorder, disp_fit_nknots, 
                                       fit_threshold, slit_spa_norm_profile,
                                       slit_disp_norm_profile);
-        float mean_disp_profile_flux = 
-            std::accumulate(slit_disp_norm_profile.begin(), 
-                            slit_disp_norm_profile.end(), 0.);
-        mean_disp_profile_flux /= slit_disp_norm_profile.size();
-        
+
+        //Get the pixel of the waveref at the middle of the slit
+        double pix_waveref = wave_cal.get_pixel((yhig + ylow) / 2.,
+                                                wave_cal.get_refwave());
+        int pix_waveref_left = (int)std::floor(pix_waveref);
+        int pix_waveref_rigth = (int)std::ceil(pix_waveref);
+        //Normalise by the value at waveref
+        double prof_val_waveref = 1;
+        if(pix_waveref_left>=0 && pix_waveref_rigth < flat.size_dispersion())
+            prof_val_waveref = (slit_disp_norm_profile[pix_waveref_left] +
+                                slit_disp_norm_profile[pix_waveref_rigth]) / 2.;
         for(size_t i_prof = 0; i_prof < slit_disp_norm_profile.size(); i_prof++)
-            slit_disp_norm_profile[i_prof] /= mean_disp_profile_flux;
+            slit_disp_norm_profile[i_prof] /= prof_val_waveref;
 
         m_wave_profiles.push_back(slit_disp_norm_profile);
+        m_wave_profiles_norm.push_back(prof_val_waveref);
         
         cpl_image * exslit = normslit.get_cpl_image();
         
@@ -384,9 +392,7 @@ int fors::flat_normaliser::mos_normalise
     cpl_image_divide(flat_im, smo_flat);
     cpl_image_divide(flat_err, smo_flat);
 
-    
-    //TODO: This is giving some segmentation fault. Fix it 
-    //m_normalisation_image = mosca::image(smo_flat);
+    m_normalisation_image = mosca::image(smo_flat, true);
     
     return 0;
 }
@@ -417,6 +423,7 @@ int fors::flat_normaliser::mos_normalise
  */
 int fors::flat_normaliser::lss_normalise
 (mosca::image& flat,
+ const mosca::wavelength_calibration& wave_cal,
  int spa_smooth_radius, int disp_smooth_radius, 
  int spa_fit_polyorder, int disp_fit_nknots,
  double fit_threshold)
@@ -452,23 +459,28 @@ int fors::flat_normaliser::lss_normalise
                                   spa_fit_polyorder, disp_fit_nknots, 
                                   fit_threshold, slit_spa_norm_profile,
                                   slit_disp_norm_profile);
-    float mean_disp_profile_flux = 
-        std::accumulate(slit_disp_norm_profile.begin(), 
-                        slit_disp_norm_profile.end(), 0.);
-    mean_disp_profile_flux /= slit_disp_norm_profile.size();
-    
+    //Get the pixel of the waveref at the middle of the slit
+    double pix_waveref = wave_cal.get_pixel(flat.size_spatial() / 2.,
+                                            wave_cal.get_refwave());
+    int pix_waveref_left = std::floor(pix_waveref);
+    int pix_waveref_rigth = std::ceil(pix_waveref);
+    //Normalise by the value at waveref
+    double prof_val_waveref = 1;
+    if(pix_waveref_left>=0 && pix_waveref_rigth < flat.size_dispersion())
+        prof_val_waveref = (slit_disp_norm_profile[pix_waveref_left] +
+                            slit_disp_norm_profile[pix_waveref_rigth]) / 2.;
     for(size_t i_prof = 0; i_prof < slit_disp_norm_profile.size(); i_prof++)
-        slit_disp_norm_profile[i_prof] /= mean_disp_profile_flux;
+        slit_disp_norm_profile[i_prof] /= prof_val_waveref;
 
     m_wave_profiles.push_back(slit_disp_norm_profile);
+    m_wave_profiles_norm.push_back(prof_val_waveref);
 
 
     //Finally divide by the smoothed version of the flat.
     cpl_image_divide(flat_im, normslit.get_cpl_image());
     cpl_image_divide(flat_err, normslit.get_cpl_image());
 
-    //TODO: This is giving some segmentation fault. Fix it 
-    //m_normalisation_image = normslit;
+    m_normalisation_image = normslit;
     
     return 0;
 }
@@ -483,6 +495,11 @@ const std::vector<std::vector<float> >& fors::flat_normaliser::get_wave_profiles
     return m_wave_profiles;
 }
 
+const std::vector<float>& fors::flat_normaliser::get_wave_profiles_norm() const
+{
+    return m_wave_profiles_norm;
+}
+
 cpl_image * fors::flat_normaliser::get_wave_profiles_im() const
 {
     cpl_image * wave_profiles_im = 
