@@ -30,6 +30,7 @@
 
 #include <cpl.h>
 #include "mosca_image.h"
+#include "wavelength_calibration.h"
 
 namespace fors
 {
@@ -42,23 +43,28 @@ public:
     flat_normaliser();
     ~flat_normaliser();
     
-    int mos_normalise(mosca::image& flat, cpl_image *spatial, 
+    int mos_normalise(mosca::image& flat, 
+                      const mosca::wavelength_calibration& wave_cal,
+                      cpl_image *spatial, 
                       cpl_table *slits, cpl_table *polytraces, 
-                      double reference, double blue, double red, 
+                      double blue, double red, 
                       double dispersion,
                       int spa_smooth_radius, int disp_smooth_radius, 
                       int spa_fit_polyorder, int disp_fit_nknots,
                       double fit_threshold);
     
-    int lss_normalise(mosca::image& flat,
-                       int spa_smooth_radius, int disp_smooth_radius, 
-                       int spa_fit_polyorder, int disp_fit_nknots,
-                       double fit_threshold);
+    int lss_normalise(mosca::image& flat, 
+                      const mosca::wavelength_calibration& wave_cal,
+                      int spa_smooth_radius, int disp_smooth_radius, 
+                      int spa_fit_polyorder, int disp_fit_nknots,
+                      double fit_threshold);
 
     const mosca::image& get_normalisation_image() const;
     
     const std::vector<std::vector<float> >& get_wave_profiles() const;
     
+    const std::vector<float>& get_wave_profiles_norm() const;
+    
     cpl_image * get_wave_profiles_im() const;
 
 private:
@@ -67,6 +73,7 @@ private:
     
     std::vector<std::vector<float> > m_wave_profiles;
     
+    std::vector<float> m_wave_profiles_norm;
     
 };
 
