@@ -127,7 +127,9 @@ fors_image_new(cpl_image *data, cpl_image *variance)
             cpl_image_get_size_x(variance), cpl_image_get_size_y(variance));
 
     assure( cpl_image_get_min(variance) >= 0, return NULL,
-            "Variances must be non-negative, minimum is %f",
+            "Variances must be non-negative, minimum is %g. \n" 
+            "This is most likely a software bug. "
+            "You may contact usd-help@eso.org which can provide a workaround.",
             cpl_image_get_min(variance));
 
     image = cpl_malloc(sizeof(*image));
@@ -1768,7 +1770,7 @@ hdrl_imagelist * fors_image_list_to_hdrl(const fors_image_list * imalist)
         const cpl_image * ima_data  = target->data;
         cpl_image * ima_error = cpl_image_power_create(target->variance, 0.5);
         cpl_mask * old_bpm = cpl_image_set_bpm(ima_error, 
-                               cpl_mask_duplicate(cpl_image_get_bpm(ima_data)));
+                               cpl_mask_duplicate(cpl_image_get_bpm_const(ima_data)));
         cpl_mask_delete(old_bpm);
         hdrl_image * ima_hdrl = hdrl_image_create(ima_data, ima_error);
         hdrl_imagelist_set(images_hdrl, ima_hdrl, 
