@@ -32,11 +32,14 @@
 CPL_BEGIN_DECLS
 
 cpl_table *fors_compute_response
-(cpl_image *spectra, double startwave, double dispersion, double gain,
+(cpl_image *spectra, cpl_image * mapped_flat_disp_profile,
+ cpl_propertylist * flat_disp_header, cpl_table *objects,
+ double startwave, double dispersion, double gain,
  double exptime, cpl_table *ext_table, double airmass, cpl_table *flux_table,
  const std::vector<double>& ignored_waves,
  const std::vector<std::pair<double, double> >& ignored_wave_ranges,
- int order);
+ int nknots, int degree, cpl_table *& response_interp,
+ double& flat_sed_norm_factor);
 
 CPL_END_DECLS
 
