@@ -70,6 +70,8 @@ cpl_image *mos_wavelength_calibration_raw(const cpl_image *image,
 cpl_error_code mos_interpolate_wavecalib_slit(cpl_table *, cpl_table *, 
                                               int, int);
 cpl_error_code mos_interpolate_wavecalib(cpl_table *, cpl_image *, int, int);
+cpl_error_code mos_interpolate_wavecalib_mos(cpl_table *idscoeff, 
+                                             int mode, int degree);
 cpl_table *mos_locate_spectra(cpl_mask *);
 cpl_error_code mos_validate_slits(cpl_table *);
 cpl_error_code mos_rotate_slits(cpl_table *, int, int, int);
@@ -129,7 +131,7 @@ double mos_distortions_rms(cpl_image *, cpl_vector *, double, double, int, int);
 cpl_image *mos_spatial_map(cpl_image *, cpl_table *, cpl_table *, double,
                            double, double, double);
 cpl_image *mos_detect_objects(cpl_image *, cpl_table *, int, int, int);
-cpl_image **mos_extract_objects(cpl_image *, cpl_image *, cpl_table *, 
+cpl_image **mos_extract_objects(cpl_image *,  cpl_image *science_var, cpl_image *, cpl_table *, 
                                 int, double, double, int);
 int mos_spectral_resolution(cpl_image *, double, double, double, int,
                             double *, double *, double *, double *, int *);
@@ -172,7 +174,8 @@ int mos_rebin_error(cpl_image **, int);
 cpl_table *mos_photometric_calibration(cpl_image *, double, double, double,
                                  double, cpl_table *, double, cpl_table *,
                                  int);
-int map_table(cpl_image *, double, double, cpl_table *, char *, char *);
+int map_table(cpl_image *, double, double, cpl_table *, 
+              const char *, const char *);
 cpl_image *mos_ksigma_stack(cpl_imagelist *imlist,
                             double klow, double khigh, int kiter,
                             cpl_image **);
