@@ -93,6 +93,7 @@ const char *const FORS_DATA_STD_NAME = "OBJECT";
 
 static const int det_nx = 400;        /* Unbinned detector pixels */
 static const int det_ny = 400;
+static const int pres_nx = 5;
 static const int binx = 2;
 static const int biny = 2;
 static const double ron   = 4.0;       /* ADU */
@@ -145,19 +146,27 @@ create_standard_keys(cpl_propertylist *header, double exptime)
     cpl_propertylist_update_double(header, FORS_PFITS_AIRMASS_START, 1.156);    
     cpl_propertylist_update_double(header, FORS_PFITS_AIRMASS_END  , 1.619);    
     
+    cpl_propertylist_update_int   (header, "HIERARCH ESO DET CHIP1 NX", nx);
+    cpl_propertylist_update_int   (header, "HIERARCH ESO DET CHIP1 NY", ny);
+    cpl_propertylist_update_int   (header, "HIERARCH ESO DET OUT1 X", 1);
+    cpl_propertylist_update_int   (header, "HIERARCH ESO DET OUT1 Y", 1);
+    cpl_propertylist_update_double(header, "HIERARCH ESO DET CHIP1 PSZX", 15.0);
+    cpl_propertylist_update_double(header, "HIERARCH ESO DET CHIP1 PSZY", 15.0);
+    cpl_propertylist_update_int   (header, FORS_PFITS_DET_NY, ny);
     cpl_propertylist_update_int   (header, FORS_PFITS_DET_NX, nx);
     cpl_propertylist_update_int   (header, FORS_PFITS_DET_NY, ny);
     cpl_propertylist_update_int   (header, FORS_PFITS_BINX, binx);
     cpl_propertylist_update_int   (header, FORS_PFITS_BINY, biny);
     cpl_propertylist_update_int   (header, FORS_PFITS_OVERSCANX, 0);
     cpl_propertylist_update_int   (header, FORS_PFITS_OVERSCANY, 0);
-    cpl_propertylist_update_int   (header, FORS_PFITS_PRESCANX, 0);
+    cpl_propertylist_update_int   (header, FORS_PFITS_PRESCANX, pres_nx);
     cpl_propertylist_update_int   (header, FORS_PFITS_PRESCANY, 0);
 
     cpl_propertylist_update_double(header, FORS_PFITS_PIXSCALE, 0.126);
     
     cpl_propertylist_update_int(header, FORS_PFITS_OUTPUTS, 1);
     cpl_propertylist_update_double(header, FORS_PFITS_CONAD[0], conad);
+    cpl_propertylist_update_double(header, "HIERARCH ESO DET OUT1 GAIN", 1./conad);
     
     /* Convert RON to e- units */
     cpl_propertylist_update_double(header, FORS_PFITS_RON[0], ron*conad);
@@ -220,7 +229,7 @@ do { \
 cpl_frame *
 create_bias(const char *filename, const char *tag, cpl_frame_group group)
 {
-    int nx = det_nx / binx;
+    int nx = det_nx / binx + pres_nx;
     int ny = det_ny / biny;
     double exptime = 0.0;
     
@@ -252,6 +261,51 @@ create_bias(const char *filename, const char *tag, cpl_frame_group group)
     return frame_new(filename, tag, group);
 }
 
+/**
+ * @brief   Simulate master bias image
+ * @param   filename        save to this file
+ * @param   tag             output frame tag
+ * @param   tag             output frame group
+ * @return  bias frame
+ *
+ * Model: constant + gaussian noise, rounded to nearest integer
+ */
+cpl_frame *
+create_master_bias(const char *filename, const char *tag, cpl_frame_group group)
+{
+    int nx = det_nx / binx;
+    int ny = det_ny / biny;
+    double exptime = 0.0;
+    
+    cpl_image *data     = cpl_image_new(nx, ny, FORS_IMAGE_TYPE);
+    cpl_image *variance = cpl_image_new(nx, ny, FORS_IMAGE_TYPE);
+    fors_image *bias = NULL;
+    cpl_propertylist *header = cpl_propertylist_new();
+    
+    create_standard_keys(header, exptime);
+    cpl_propertylist_erase(header, FORS_PFITS_FILTER_NAME); /* No filter */
+    cpl_propertylist_append_double(header, "ESO QC DET OUT1 RON",4.44); /* No filter */
+
+    {
+        int x, y;
+        for (y = 1; y <= ny; y++)
+            for (x = 1; x <= nx; x++) {
+                cpl_image_set(data   , x, y, 
+                              (int)(ron*fors_rand_gauss() + 0.5)); //Overscan already removed
+                cpl_image_set(variance, x, y, ron*ron);
+            }
+    }
+    
+    bias = fors_image_new(data, variance);
+    fors_image_save(bias, header, filename);
+
+    assure( !cpl_error_get_code(), return NULL,
+            "Saving master bias to %s failed", filename );
+
+    cleanup;
+    return frame_new(filename, tag, group);
+}
+
 #undef cleanup
 #define cleanup \
 do { \
@@ -272,7 +326,7 @@ do { \
 cpl_frame *
 create_dark(const char *filename, const char *tag, cpl_frame_group group)
 {
-    int nx = det_nx / binx;
+    int nx = det_nx / binx + pres_nx;
     int ny = det_ny / biny;
     double exptime = 3.0;
     
@@ -295,6 +349,14 @@ create_dark(const char *filename, const char *tag, cpl_frame_group group)
                                     + 0.5));
                 cpl_image_set(variance, x, y, var);
             }
+        //Fill the prescan region
+        for (y = 1; y <= ny; y++)
+            for (x = 1; x <= pres_nx; x++)
+            {
+                cpl_image_set(data   , x, y, 
+                              (int)(bias_avg + ron*fors_rand_gauss() + 0.5));
+                cpl_image_set(variance, x, y, ron*ron);
+            }
     }
     
     dark = fors_image_new(data, variance);
@@ -327,7 +389,7 @@ do { \
 cpl_frame *
 create_screen_flat(const char *filename, const char *tag, cpl_frame_group group)
 {
-    int nx = det_nx / binx;
+    int nx = det_nx / binx + pres_nx;
     int ny = det_ny / biny;
     double exptime = 3.0;
 
@@ -351,6 +413,14 @@ create_screen_flat(const char *filename, const char *tag, cpl_frame_group group)
                               (int)(bias_avg + flat + sqrt(var)*fors_rand_gauss() + 0.5));
                 cpl_image_set(variance, x, y, var);
             }
+        //Fill the prescan region
+        for (y = 1; y <= ny; y++)
+            for (x = 1; x <= pres_nx; x++)
+            {
+                cpl_image_set(data   , x, y, 
+                              (int)(bias_avg + ron*fors_rand_gauss() + 0.5));
+                cpl_image_set(variance, x, y, ron*ron);
+            }
     }
     
     sflat = fors_image_new(data, variance);
@@ -383,6 +453,67 @@ do { \
 cpl_frame *
 create_sky_flat(const char *filename, const char *tag, cpl_frame_group group,
                 double exptime)
+{
+    int nx = det_nx / binx + pres_nx;
+    int ny = det_ny / biny;
+
+    cpl_image *data     = cpl_image_new(nx, ny, FORS_IMAGE_TYPE);
+    cpl_image *variance = cpl_image_new(nx, ny, FORS_IMAGE_TYPE);
+    fors_image *sflat = NULL;
+    cpl_propertylist *header = cpl_propertylist_new();
+    
+    create_standard_keys(header, exptime);
+
+    {
+        int x, y;
+        for (y = 1; y <= ny; y++)
+            for (x = 1; x <= nx; x++) {
+                double medium_scale_structure = 1000*(2 + sin(x*30.0/nx - y*10.0/ny));
+                double  large_scale_structure = 1000*(1 + sin(x*4.0/nx));
+                double flat = exptime*(5000 + 
+                                       medium_scale_structure + 
+                                       large_scale_structure);
+                double var = ron*ron + flat/conad;
+                
+                cpl_image_set(data   , x, y, 
+                              (int)(flat + sqrt(var)*fors_rand_gauss() + 0.5));//Overscan already removed
+                cpl_image_set(variance, x, y, var);
+            }
+        //Fill the prescan region
+        for (y = 1; y <= ny; y++)
+            for (x = 1; x <= pres_nx; x++)
+            {
+                cpl_image_set(data   , x, y, 
+                              (int)(bias_avg + ron*fors_rand_gauss() + 0.5));
+                cpl_image_set(variance, x, y, ron*ron);
+            }
+    }
+    
+    sflat = fors_image_new(data, variance);
+    fors_image_save(sflat, header, filename);
+
+    assure( !cpl_error_get_code(), return NULL, 
+            "Saving sky flat to %s failed", filename );
+
+    cleanup;
+    return frame_new(filename, tag, group);
+}
+
+/**
+ * @brief   Simulate master sky flat image
+ * @param   filename        save to this file
+ * @param   tag             output frame tag
+ * @param   group           output frame group
+ * @param   exptime         exposure time
+ * @return  sky flat frame
+ *
+ * Model:     bias   + flat(x,y)
+ * Variance = ron**2 + flat(x,y)/conad
+ */
+cpl_frame *
+create_master_sky_flat(const char *filename, 
+                       const char *tag, cpl_frame_group group,
+                       double exptime)
 {
     int nx = det_nx / binx;
     int ny = det_ny / biny;
@@ -406,7 +537,7 @@ create_sky_flat(const char *filename, const char *tag, cpl_frame_group group,
                 double var = ron*ron + flat/conad;
                 
                 cpl_image_set(data   , x, y, 
-                              (int)(bias_avg + flat + sqrt(var)*fors_rand_gauss() + 0.5));
+                              (int)(flat + sqrt(var)*fors_rand_gauss() + 0.5));//Overscan already removed
                 cpl_image_set(variance, x, y, var);
             }
     }
