@@ -88,7 +88,7 @@ mosca::wavelength_calibration::wavelength_calibration
     m_refwave = rhs.m_refwave;
 
     std::vector<cpl_polynomial *>::const_iterator poly;
-    for(poly = rhs.m_wave_coeff.begin(); poly != rhs.m_wave_coeff.end(); poly++)
+    for(poly = rhs.m_wave_coeff.begin(); poly != rhs.m_wave_coeff.end(); ++poly)
     {
         if(*poly != NULL)
             m_wave_coeff.push_back(cpl_polynomial_duplicate(*poly));
@@ -97,6 +97,8 @@ mosca::wavelength_calibration::wavelength_calibration
     }
 }
 
+//TODO: Create a copy operator (copy constructor is not trivial)
+
 void mosca::wavelength_calibration::from_idscoeff
 (const cpl_table * idscoeff, double refwave)
 {
@@ -134,14 +136,30 @@ void mosca::wavelength_calibration::from_idscoeff
 mosca::wavelength_calibration::~wavelength_calibration()
 {
     std::vector<cpl_polynomial *>::iterator poly;
-    for(poly = m_wave_coeff.begin(); poly != m_wave_coeff.end(); poly++)
+    for(poly = m_wave_coeff.begin(); poly != m_wave_coeff.end(); ++poly)
     {
         if(*poly != NULL)
             cpl_polynomial_delete(*poly);
     }
 }
 
-//Starting at 0 or 1?
+double mosca::wavelength_calibration::get_pixel(double spatial_corrected_pos,
+                                                double wavelength) const
+{
+    double pixel = -1;
+    size_t row = (size_t)(spatial_corrected_pos);
+    if(row >= m_wave_coeff.size())
+        return pixel;
+    
+    cpl_polynomial * poly = m_wave_coeff[row];
+    if(poly == NULL)
+        return pixel;
+
+    pixel = cpl_polynomial_eval_1d(poly, wavelength - m_refwave, NULL);
+    return pixel;
+}
+
+//TODO:Starting at 0 or 1?
 double mosca::wavelength_calibration::get_wave(double spatial_corrected_pos,
                                                double dispersion_pos) const
 {
@@ -172,9 +190,6 @@ double mosca::wavelength_calibration::get_wave(double spatial_corrected_pos,
         return -1;
     }
 
-  //Commmented out becuase it is wrong, I think. It is how it was done before  
-//        wavelength = cpl_polynomial_eval_1d(poly, dispersion_pos, NULL);
-    
     cpl_polynomial_delete(inv_poly);
     return wavelength + m_refwave;
 }
@@ -220,6 +235,21 @@ double mosca::wavelength_calibration::mean_dispersion(int size_dispersion,
     
     double mean_disp = (max_wave - min_wave) / size_dispersion;
     
+    //TODO:Maybe it should be done this way:
+    //cpl_msg_warning(cpl_func, " mean disp %f", mean_disp);
+    //std::vector<double> c1s;
+    //for(int irow = min_spa_row ; irow < max_spa_row; ++irow)
+    //{
+    //    cpl_polynomial * poly = m_wave_coeff[irow];
+    //    if(poly != NULL)
+    //    {
+    //        cpl_size c1_idx = 1;
+    //        double c1 = cpl_polynomial_get_coeff(poly, &c1_idx);
+    //        c1s.push_back(c1);
+    //    }
+    //}
+    //cpl_msg_warning(cpl_func, " aver c1 %f", mean(c1s.begin(), c1s.end()));
+    
     return mean_disp;
 }
 
@@ -235,3 +265,29 @@ bool mosca::wavelength_calibration::has_valid_cal
     
     return true;
 }
+
+bool mosca::wavelength_calibration::is_monotonical
+(size_t spa_row, double start_wave, double end_wave, double dispersion) const
+{
+    if(spa_row >= m_wave_coeff.size())
+        return false;
+    cpl_polynomial * poly = m_wave_coeff[spa_row];
+    if(poly == NULL)
+        return false;
+    
+    for(double wave = start_wave; wave <= end_wave; wave += dispersion)
+    {
+        double grad;
+        cpl_polynomial_eval_1d(poly, wave - m_refwave, &grad);
+        
+        if(grad <= 0)
+            return false;
+    }
+    
+    return true;
+}
+
+double mosca::wavelength_calibration::get_refwave() const
+{
+    return m_refwave;
+}
