@@ -55,6 +55,8 @@ public:
   
     void from_idscoeff(const cpl_table * idscoeff, double refwave);
     
+    double get_pixel(double spatial_corrected_pos, double wavelength) const;
+
     double get_wave(double spatial_corrected_pos, double dispersion_pos) const;
     
     void min_max_wave(double& min_wave, double &max_wave, int size_dispersion,
@@ -67,6 +69,10 @@ public:
     
     bool has_valid_cal(double spatial_corrected_pos) const;
 
+    bool is_monotonical(size_t spa_row, double start_wave, double end_wave, 
+                        double dispersion) const;
+
+    double get_refwave() const;
 
     
 private:
