@@ -563,13 +563,13 @@ static int fors_detect_spectra(cpl_parameterlist *parlist,
         fors_detect_spectra_exit("Too many in input: MASTER_LINECAT");
 
     if (!dfs_equal_keyword(frameset, "ESO INS GRIS1 ID"))
-        fors_detect_spectra_exit("Input frames are not from the same grism");
+        cpl_msg_warning(cpl_func,"Input frames are not from the same grism");
 
     if (!dfs_equal_keyword(frameset, "ESO INS FILT1 ID"))
-        fors_detect_spectra_exit("Input frames are not from the same filter");
+        cpl_msg_warning(cpl_func,"Input frames are not from the same filter");
 
     if (!dfs_equal_keyword(frameset, "ESO DET CHIP1 ID"))
-        fors_detect_spectra_exit("Input frames are not from the same chip");
+        cpl_msg_warning(cpl_func,"Input frames are not from the same chip");
 
 
     /*
