@@ -35,6 +35,7 @@
 #include <fors_dfs.h>
 #include <fors_utils.h>
 #include <fors_flat_normalise.h>
+#include "wavelength_calibration.h"
 
 static int fors_normalise_flat_create(cpl_plugin *);
 static int fors_normalise_flat_exec(cpl_plugin *);
@@ -68,9 +69,10 @@ static char fors_normalise_flat_description[] =
 "Input files:\n\n"
 "  DO category:               Type:       Explanation:         Required:\n"
 "  MASTER_SCREEN_FLAT_MXU     Calib       Master flat frame       Y\n"
+"  DISP_COEFF_MXU             Calib       Wavelength calibration  Y\n"        
 "  CURV_COEFF_MXU             Calib       Spectral curvature      .\n"
-"  SLIT_LOCATION_MXU          Calib       Spectral curvature      .\n"        
-"  GRISM_TABLE                Calib       Grism table             .\n\n"
+"  SLIT_LOCATION_MXU          Calib       Slit detection          .\n"        
+"  GRISM_TABLE                Calib       Grism table             Y\n\n"
 "Output files:\n\n"
 "  DO category:               Data type:  Explanation:\n"
 "  MASTER_NORM_FLAT_MXU       FITS image  Normalised flat field\n\n";
@@ -407,6 +409,7 @@ static int fors_normalise_flat(cpl_parameterlist *parlist,
     const char *master_norm_flat_tag = NULL;
     const char *slit_location_tag = NULL;
     const char *curv_coeff_tag = NULL;
+    const char *disp_coeff_tag = NULL;
     int         mxu, mos, lss;
     int         nflat;
     int         rebin;
@@ -496,16 +499,19 @@ static int fors_normalise_flat(cpl_parameterlist *parlist,
         master_norm_flat_tag = "MASTER_NORM_FLAT_MXU";
         slit_location_tag    = "SLIT_LOCATION_MXU";
         curv_coeff_tag       = "CURV_COEFF_MXU";
+        disp_coeff_tag       = "DISP_COEFF_MXU";
     }
     else if (mos) {
         master_flat_tag      = "MASTER_SCREEN_FLAT_MOS";
         master_norm_flat_tag = "MASTER_NORM_FLAT_MOS";
         slit_location_tag    = "SLIT_LOCATION_MOS";
         curv_coeff_tag       = "CURV_COEFF_MOS";
+        disp_coeff_tag       = "DISP_COEFF_MOS";
     }
     else if (lss) {
         master_flat_tag      = "MASTER_SCREEN_FLAT_LSS";
         master_norm_flat_tag = "MASTER_NORM_FLAT_LSS";
+        disp_coeff_tag       = "DISP_COEFF_LSS";
     }
 
     header = dfs_load_header(frameset, master_flat_tag, 0);
@@ -531,36 +537,35 @@ static int fors_normalise_flat(cpl_parameterlist *parlist,
                             "The LSS data reduction strategy is applied!");
     }
 
+    /* Check for required inputs */
+    if (cpl_frameset_count_tags(frameset, disp_coeff_tag) != 0) {
+        cpl_msg_error(recipe, "One (and only one) %s must be in inputs", 
+                      slit_location_tag);
+        fors_normalise_flat_exit(NULL);
+    }
     if (!(lss || treat_as_lss)) {
-        if (cpl_frameset_count_tags(frameset, curv_coeff_tag) == 0) {
-            cpl_msg_error(recipe, "Missing input: %s", curv_coeff_tag);
+        if (cpl_frameset_count_tags(frameset, curv_coeff_tag) != 1) {
+            cpl_msg_error(recipe, "One (and only one) %s must be in inputs", 
+                          curv_coeff_tag);
             fors_normalise_flat_exit(NULL);
         }
 
-        if (cpl_frameset_count_tags(frameset, curv_coeff_tag) > 1) {
-            cpl_msg_error(recipe, "Too many in input: %s", curv_coeff_tag);
-            fors_normalise_flat_exit(NULL);
-        }
 
-        if (cpl_frameset_count_tags(frameset, slit_location_tag) == 0) {
-            cpl_msg_error(recipe, "Missing input: %s", slit_location_tag);
-            fors_normalise_flat_exit(NULL);
-        }
-
-        if (cpl_frameset_count_tags(frameset, slit_location_tag) > 1) {
-            cpl_msg_error(recipe, "Too many in input: %s", slit_location_tag);
+        if (cpl_frameset_count_tags(frameset, slit_location_tag) != 0) {
+            cpl_msg_error(recipe, "One (and only one) %s must be in inputs", 
+                          slit_location_tag);
             fors_normalise_flat_exit(NULL);
         }
     }
 
     if (!dfs_equal_keyword(frameset, "ESO INS GRIS1 ID"))
-        fors_normalise_flat_exit("Input frames are not from the same grism");
+        cpl_msg_warning(cpl_func,"Input frames are not from the same grism");
 
     if (!dfs_equal_keyword(frameset, "ESO INS FILT1 ID"))
-        fors_normalise_flat_exit("Input frames are not from the same filter");
+        cpl_msg_warning(cpl_func,"Input frames are not from the same filter");
 
     if (!dfs_equal_keyword(frameset, "ESO DET CHIP1 ID"))
-        fors_normalise_flat_exit("Input frames are not from the same chip");
+        cpl_msg_warning(cpl_func,"Input frames are not from the same chip");
 
 
     /*
@@ -612,7 +617,7 @@ static int fors_normalise_flat(cpl_parameterlist *parlist,
                         dispersion);
     }
 
-
+    /* Load flat frame */
     cpl_msg_indent_less();
     cpl_msg_info(recipe, "Load input frames...");
     cpl_msg_indent_more();
@@ -625,6 +630,11 @@ static int fors_normalise_flat(cpl_parameterlist *parlist,
                              cpl_image_power_create(master_flat_f->variance, 0.5),
                              true, mosca::X_AXIS);
 
+    /* Load wavelength calibration */
+    cpl_table * disp_coeff = dfs_load_table(frameset, disp_coeff_tag, 1);
+    if (disp_coeff == NULL)
+        fors_normalise_flat_exit("Cannot load wave calib table");
+    mosca::wavelength_calibration wave_cal(disp_coeff, reference);
 
     cpl_msg_indent_less();
     cpl_msg_info(recipe, "Perform flat field normalisation...");
@@ -649,7 +659,7 @@ static int fors_normalise_flat(cpl_parameterlist *parlist,
          * curvature model may be provided in input, in future releases.
          */
 
-        normaliser.lss_normalise(master_flat, sradius, dradius, 
+        normaliser.lss_normalise(master_flat, wave_cal, sradius, dradius, 
                                  spa_polyorder, disp_nknots, splfit_threshold);
     }
     else
@@ -679,8 +689,8 @@ static int fors_normalise_flat(cpl_parameterlist *parlist,
 
         cpl_image_delete(spatial); spatial = NULL;
 
-        normaliser.mos_normalise(master_flat, coordinate, slits, polytraces,
-                reference, startwavelength, endwavelength,
+        normaliser.mos_normalise(master_flat, wave_cal, coordinate, slits, polytraces,
+                startwavelength, endwavelength,
                 dispersion, sradius, dradius,
                 spa_polyorder, disp_nknots, splfit_threshold);
 
