@@ -868,13 +868,13 @@ static int fors_pmos_calib(cpl_parameterlist *parlist, cpl_frameset *frameset)
         cpl_frameset_erase(subframeset, "MASTER_BIAS");
 
         if (!dfs_equal_keyword(subframeset, "ESO INS GRIS1 ID")) 
-            fors_pmos_calib_exit("Input frames are not from the same grism");
+            cpl_msg_warning(cpl_func,"Input frames are not from the same grism");
     
         if (!dfs_equal_keyword(subframeset, "ESO INS FILT1 ID")) 
-            fors_pmos_calib_exit("Input frames are not from the same filter");
+            cpl_msg_warning(cpl_func,"Input frames are not from the same filter");
     
         if (!dfs_equal_keyword(subframeset, "ESO DET CHIP1 ID")) 
-            fors_pmos_calib_exit("Input frames are not from the same chip");
+            cpl_msg_warning(cpl_func,"Input frames are not from the same chip");
 
         cpl_frameset_delete(subframeset);
     }
