@@ -428,13 +428,13 @@ static int fors_flat(cpl_parameterlist *parlist, cpl_frameset *frameset)
     }
 
     if (!dfs_equal_keyword(frameset, "ESO INS GRIS1 ID"))
-        fors_flat_exit("Input frames are not from the same grism");
+        cpl_msg_warning(cpl_func,"Input frames are not from the same grism");
 
     if (!dfs_equal_keyword(frameset, "ESO INS FILT1 ID"))
-        fors_flat_exit("Input frames are not from the same filter");
+        cpl_msg_warning(cpl_func,"Input frames are not from the same filter");
 
     if (!dfs_equal_keyword(frameset, "ESO DET CHIP1 ID")) 
-        fors_flat_exit("Input frames are not from the same chip");
+        cpl_msg_warning(cpl_func,"Input frames are not from the same chip");
 
     header = dfs_load_header(frameset, flat_tag, 0);
 
