@@ -54,11 +54,11 @@ try:
 
       for inst_mode in ('MXU', 'MOS', 'LSS', 'LONG_MOS', 'LONG_MXU') :
         if 'REDUCED_LAMP_'+inst_mode in frames:
-          self.lamp_reduced   = PlotableReducedArc(frames["REDUCED_LAMP_"+inst_mode])
+          self.lamp_reduced = PlotableReducedArc(frames["REDUCED_LAMP_"+inst_mode])
 
       for inst_mode in ('MXU', 'MOS', 'LSS', 'LONG_MOS', 'LONG_MXU') :
         if 'SPATIAL_MAP_'+inst_mode in frames:
-          self.slit_map   = PlotableSpatialMap(frames["SPATIAL_MAP_"+inst_mode])
+          self.slit_map = PlotableSpatialMap(frames["SPATIAL_MAP_"+inst_mode])
 
       for inst_mode in ('MXU', 'MOS', 'LSS', 'LONG_MOS', 'LONG_MXU') :
         if 'DISP_RESIDUALS_TABLE_'+inst_mode in frames:
@@ -73,15 +73,16 @@ try:
         if 'CURV_COEFF_'+inst_mode in frames :
           curv_frame = frames['CURV_COEFF_'+inst_mode]
                   
+      flat_norm = None
       for inst_mode in ('MXU', 'MOS', 'LSS', 'LONG_MOS', 'LONG_MXU') :
         if 'MASTER_NORM_FLAT_'+inst_mode in frames :
-          self.flat_norm  = PlotableNormFlat(frames['MASTER_NORM_FLAT_'+inst_mode],
-                                             curv_frame)
+          flat_norm = frames['MASTER_NORM_FLAT_'+inst_mode]
+          self.flat_norm  = PlotableNormFlat(flat_norm, curv_frame)
                   
       for inst_mode in ('MXU', 'MOS', 'LSS', 'LONG_MOS', 'LONG_MXU') :
-        if 'MASTER_SCREEN_FLAT_'+inst_mode in frames :
-          self.flat_mscreen  = PlotableFlat(frames['MASTER_SCREEN_FLAT_'+inst_mode],
-                                            curv_frame)
+        if 'SCREEN_FLAT_'+inst_mode in frames :
+          self.flat_mscreen  = PlotableRawFlat(frames['SCREEN_FLAT_'+inst_mode],
+                                               flat_norm, curv_frame)
                   
     # This function creates all the subplots. It is responsible for the plotting 
     # layouts. 
@@ -98,7 +99,7 @@ try:
         else:
           self.subplot_lamp_reduced   = figure.add_subplot(3,1,1)
         self.subplot_line_x_y       = figure.add_subplot(3,2,3)
-        self.subplot_flat_mscreen   = figure.add_subplot(3,2,4)
+        self.subplot_flat_raw       = figure.add_subplot(3,2,4)
         self.subplot_line_res_wave  = figure.add_subplot(3,2,5)
         self.subplot_flat_norm      = figure.add_subplot(3,2,6)
       else : 
@@ -155,11 +156,10 @@ Arc line coverage may vary with slit position."""
                            tooltip_slit_map)
 
     def plotScreenFlat(self) :
-      title_flat_mscreen   = 'Master screen flat frame'
-      tooltip_flat_mscreen ="""Master screen flat frame.
-This frame still contains the spectral energy distribution 
-of the lamp as well as effects of order separating filters."""
-      self.flat_mscreen.plot(self.subplot_flat_mscreen, title_flat_mscreen,
+      title_flat_mscreen   = 'First raw flat field frame'
+      tooltip_flat_mscreen ="""First raw flat field frame.
+This frame is the first raw flat frame. It serves to verify that for MOS/MXU data all slits have been detected (compare with spatial map displayed above)."""
+      self.flat_mscreen.plot(self.subplot_flat_raw, title_flat_mscreen,
                          tooltip_flat_mscreen)
 
     def plotNormalisedFlat(self) :
@@ -168,8 +168,7 @@ of the lamp as well as effects of order separating filters."""
 This is the result of the flat field normalisation. 
 For LSS data it may make sense to keep the relative
 flux variation along the slit to correct for slit illumination. 
-For MOS/MXU data this generally does not work well.
-Reduced and normalised flat frame."""
+For MOS/MXU data this generally does not work well."""
       self.flat_norm.plot(self.subplot_flat_norm, title_flat_norm,
                          tooltip_flat_norm)
 
@@ -190,6 +189,10 @@ to the --ignore_lines recipe parameter."""
     def plotLinePositions(self) :
       title_line_x_y   = 'Detected / Identified arc lines'
       tooltip_line_x_y ="""Detected/identified arc lines.
+Black points are detected lines. 
+Green points are identified lines.
+Light green points are identified lines after pattern-matching iteration
+(only if wradius >0).
 Most detected lines should also be identified. 
 If lines at the edges are not identified this means that
 the dispersion relation there will be extrapolated."""
@@ -251,6 +254,9 @@ the dispersion relation there will be extrapolated."""
       paramList.append(reflex.RecipeParameter('fors_calib','kiter',group='master flat',description='Max number of iterations in ksigma method'))
       paramList.append(reflex.RecipeParameter('fors_calib','klow',group='master flat',description='Low threshold in ksigma method'))
       paramList.append(reflex.RecipeParameter('fors_calib','khigh',group='master flat',description='High threshold in ksigma method'))
+      paramList.append(reflex.RecipeParameter('fors_calib','slit_ident',group='master flat',description='Attempt slit identification for MOS or MXU'))
+      paramList.append(reflex.RecipeParameter('fors_calib','startwavelength',group='wave calib / distorsions',description='Start wavelength in spectral extraction'))
+      paramList.append(reflex.RecipeParameter('fors_calib','endwavelength',group='wave calib / distorsions',description='End wavelength in spectral extraction'))
       paramList.append(reflex.RecipeParameter('fors_calib','wdegree',group='wave calib / distorsions',description='Degree of wave calib polynomial'))
       paramList.append(reflex.RecipeParameter('fors_calib','wradius',group='wave calib / distorsions',description='Search radius if iterating pattern-matching with first-guess method'))
       paramList.append(reflex.RecipeParameter('fors_calib','wreject',group='wave calib / distorsions',description='Rejection threshold in dispersion relation fit (pixel)'))
@@ -259,11 +265,12 @@ the dispersion relation there will be extrapolated."""
       paramList.append(reflex.RecipeParameter('fors_calib','dispersion',group='wave calib / distorsions',description='Expected spectral dispersion (Angstrom/pixel)'))
       paramList.append(reflex.RecipeParameter('fors_calib','peakdetection',group='wave calib / distorsions',description='Initial peak detection threshold (ADU)'))
       paramList.append(reflex.RecipeParameter('fors_calib','ignore_lines',group='wave calib / distorsions',description='Catalog lines nearest to wavelengths in this list will be ignored for wavelength calibration')) 
+      paramList.append(reflex.RecipeParameter('fors_calib','used_linesets',group='wave calib / distorsions',description='Linesets to use. Valid are standard and extended (see column LINE_SET in the line catalogue)')) 
       return paramList
 
     def setWindowHelp(self):
       help_text = """
-In this window, the user ..."""
+In this window, the user will interact with the Fors calibration (flat, slit traces and wavelength calibration)"""
       return help_text
 
     def setWindowTitle(self):
