@@ -100,6 +100,25 @@ class PlotableNormFlat (PlotableFlat) :
     self.flat.image[self.flat.image > 5.] = 0
     super(PlotableNormFlat, self).plot(subplot, title, tooltip)
 
+class PlotableRawFlat (PlotableFlat) :
+  def __init__(self, fits_flat_raw, fits_master_flat, fits_slittrace):
+    super(PlotableRawFlat, self).__init__(fits_flat_raw, fits_slittrace)
+    if self.slittrace is not None and fits_master_flat is not None :
+      master_flat = PipelineProduct(fits_master_flat)
+      self.trimm_lly = master_flat.all_hdu[0].header.get('HIERARCH ESO QC TRIMM LLY')
+
+      #Change the traces by the amount of overscan in Y that has been removed
+      for ypos_top in self.ypos_top_traces:
+        for j, ypos in enumerate(ypos_top):
+          ypos_top[j] = ypos + self.trimm_lly - 1
+      for ypos_bottom in self.ypos_bottom_traces:
+        for j, ypos in enumerate(ypos_bottom):
+          ypos_bottom[j] = ypos + self.trimm_lly -1
+    
+
+  def plot(self, subplot, title, tooltip):
+    super(PlotableRawFlat, self).plot(subplot, title, tooltip)
+
 class PlotableSpatialMap :
   def __init__(self, fits_spatialmap):
     self.spatialmap      = PipelineProduct(fits_spatialmap)
@@ -162,7 +181,7 @@ class PlotableMappedScience :
       subplot.autoscale(enable=False)
       for obj in range(self.nobjects) :
         subplot.axhline(self.ytop_obj_extract[obj], linestyle='solid',color='red')
-        subplot.axhline(self.ybottom_obj_extract[obj], linestyle='solid',color='blue')
+        subplot.axhline(self.ybottom_obj_extract[obj], linestyle='solid',color='yellow')
         
   def getObjectInPosition(self, ypos) :
     for obj in range(self.nobjects) :
@@ -230,22 +249,40 @@ class PlotableDetectedLines :
       self.x_pix = self.detectedlines.column
       self.detectedlines.readTableColumn(1, 'ypos_rectified')
       self.y_pix = self.detectedlines.column
+      self.detectedlines.readTableColumn(1, 'xpos_rectified_iter')
+      self.x_pix_iter = self.detectedlines.column
+      self.detectedlines.readTableColumn(1, 'ypos_rectified_iter')
+      self.y_pix_iter = self.detectedlines.column
     except KeyError:
       self.detectedlines.readTableColumn(1, 'xpos')
       self.x_pix = self.detectedlines.column
       self.detectedlines.readTableColumn(1, 'ypos')
       self.y_pix = self.detectedlines.column
+      self.detectedlines.readTableColumn(1, 'xpos_iter')
+      self.x_pix_iter = self.detectedlines.column
+      self.detectedlines.readTableColumn(1, 'ypos_iter')
+      self.y_pix_iter = self.detectedlines.column
+
       
     self.detectedlines.readTableColumn(1, 'wave_ident')
     self.wave  = self.detectedlines.column
+    self.detectedlines.readTableColumn(1, 'wave_ident_iter')
+    self.wave_iter  = self.detectedlines.column
     self.detectedlines.readTableColumn(1, 'res_xpos')
     self.res_xpos  = self.detectedlines.column
 
   def plotXVsY(self, subplot, title, tooltip):
+    #We first plot all the detected lines
     self.xydisplay.setLabels('Xpos [pix]','Ypos [pix]')
     self.xydisplay.setColor('black')
     self.xydisplay.display(subplot, title, tooltip, self.x_pix,
                            self.y_pix)
+    #We then overplot the identified lines in the second iteration
+    self.xydisplay.setColor('lightgreen')
+    self.xydisplay.display(subplot, title, tooltip,
+                           self.x_pix_iter[numpy.isfinite(self.wave_iter)],
+                           self.y_pix_iter[numpy.isfinite(self.wave_iter)])
+    #And then we overplot the identified lines in the first iteration
     self.xydisplay.setColor('green')
     self.xydisplay.display(subplot, title, tooltip, 
                            self.x_pix[numpy.isfinite(self.wave)],
@@ -284,6 +321,7 @@ class PlotableSkylinesOffsets :
   def plot(self, subplot, title, tooltip):
     self.resdisplay.setLabels('Wavelength [Ang]','Residual [Ang]')
     self.resdisplay.setColor('black')
+    self.resdisplay.setPointSize(7)
     self.resdisplay.display(subplot, title, tooltip, 
                             self.allskylines_wave, self.allwave_res)
 
@@ -311,6 +349,8 @@ class PlotableExtractedScience :
     self.setFluxSelected()
 
   def selectBrightest(self):
+    if self.nobj == 1:
+      self.obj_id = 1
     median = 0
     for obj in range(self.nobj) :
       new_median = numpy.median(self.extractedscience.image[obj,:]) 
@@ -336,23 +376,33 @@ class PlotableSpecPhot :
     self.resp     = PipelineProduct(fits)
     self.respdisp = SpectrumDisplay()
     self.tabdisp  = ScatterDisplay()
+    self.flat_sed = False
     self.loadFromFits()
 
   def loadFromFits(self) :
     self.wave         = self.resp.readTableColumn(1, 'WAVE')
+    self.wave_obs     = self.resp.readTableColumn(2, 'WAVE')
     self.std_ref_flux = self.resp.readTableColumn(1, 'STD_FLUX')
     self.std_obs_flux = self.resp.readTableColumn(1, 'OBS_FLUX')
-    self.raw_response = self.resp.readTableColumn(1, 'RAW_RESPONSE')
-    self.fit_response = self.resp.readTableColumn(1, 'RESPONSE')
+    if 'RESPONSE' in self.resp.all_hdu[2].columns.names :
+      self.fit_response = self.resp.readTableColumn(2, 'RESPONSE')
+      self.raw_response = self.resp.readTableColumn(1, 'RAW_RESPONSE')
+    else :
+      self.fit_response = self.resp.readTableColumn(2, 'RESPONSE_FFSED')
+      self.raw_response = self.resp.readTableColumn(1, 'RAW_RESPONSE_FFSED')
+      self.flat_sed = True
+    self.used_fit     = self.resp.readTableColumn(1, 'USED_FIT')
+    self.raw_response_nonnull = self.raw_response[self.raw_response > 0]
+    self.wave_nonnull = self.wave[self.raw_response > 0]
+    self.wave_used = self.wave[self.used_fit > 0]
+    self.raw_response_used = self.raw_response[self.used_fit > 0]    
 
   def plotResponse(self, subplot, title, tooltip):
     self.respdisp.setLabels('Angstrom','10^ (-16) erg/(cm^ (-2) e-)')
-    raw_response_nonnull = self.raw_response[self.raw_response > 0]
-    wave_nonnull = self.wave[self.raw_response > 0]
-    fit_response_nonnull = self.fit_response[self.raw_response > 0]
-    self.respdisp.flux_lim = 0., numpy.max(raw_response_nonnull) * 1.1
-    self.respdisp.display(subplot, title, tooltip, wave_nonnull, fit_response_nonnull, autolimits = False)
-    subplot.scatter(wave_nonnull, raw_response_nonnull, color='green')
+    self.respdisp.flux_lim = 0., numpy.max(self.raw_response_nonnull) * 1.1
+    self.respdisp.display(subplot, title, tooltip, self.wave_obs, self.fit_response, autolimits = False)
+    subplot.scatter(self.wave_nonnull, self.raw_response_nonnull, color='darkblue')
+    subplot.scatter(self.wave_used, self.raw_response_used, color='lightgreen')
 
   def plotStdExtracted(self, subplot, title, tooltip):
     self.respdisp.setLabels('Angstrom','e-/ (s Angstrom)')
@@ -366,23 +416,23 @@ class PlotableSpecPhot :
     self.tabdisp.display(subplot, title, tooltip, self.wave, self.std_ref_flux)
 
 class PlotableStdTabRedFlux :
-  def __init__(self, reducedfluxstd_fits, reducedstd_fits, stdflux_fits):
-    self.stdflux        = PipelineProduct(stdflux_fits)
+  def __init__(self, reducedfluxstd_fits, reducedstd_fits, specphot_fits):
     self.reducedfluxstd = PlotableExtractedScience(reducedfluxstd_fits)
     self.reducedstd     = PlotableExtractedScience(reducedstd_fits)
+    self.specphot       = PlotableSpecPhot(specphot_fits)
     self.tabstddisp     = ScatterDisplay()
     self.stdreddisp     = ScatterDisplay()
     self.loadFromFits()
 
   def loadFromFits(self) :
-    self.std_tab_wave     = self.stdflux.readTableColumn(1, 'WAVE')
-    self.std_tab_flux     = self.stdflux.readTableColumn(1, 'FLUX')
-    self.bin              = self.stdflux.readTableColumn(1, 'BIN')
-
     #This will select the brightest spectrum, which is the criteria
     #used to extract the standard star
     self.reducedfluxstd.loadFromFits()
     self.reducedstd.loadFromFits()
+    self.specphot.loadFromFits()
+    self.std_ref_flux_nonnull = self.specphot.std_ref_flux[self.specphot.raw_response > 0]
+    self.std_ref_flux_used = self.specphot.std_ref_flux[self.specphot.used_fit > 0]
+    
 
   def plotStdTabRedFlux(self, subplot, title, tooltip) :
     self.tabstddisp.setLabels('Angstrom','10^ (-16) erg/(cm^ (-2) Angstrom)')
@@ -393,10 +443,11 @@ class PlotableStdTabRedFlux :
     self.tabstddisp.setColor('red') 
     self.tabstddisp.display(subplot, title, tooltip, 
                             self.reducedfluxstd.wave, self.reducedfluxstd.flux)
-    self.tabstddisp.setColor('blue') 
+    self.tabstddisp.setColor('darkblue') 
     self.tabstddisp.setPointSize(20) 
-    self.tabstddisp.display(subplot, title, tooltip, 
-                            self.std_tab_wave, self.std_tab_flux)
+    subplot.scatter(self.specphot.wave, self.specphot.std_ref_flux)
+    subplot.scatter(self.specphot.wave_used, self.std_ref_flux_used, color='lightgreen')
+
 
   def plotStdRed(self, subplot, title, tooltip) :
     self.stdreddisp.setLabels('Angstrom','10^ (-16) erg/(cm^ (-2) Angstrom)')
